@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Glib::Object::Introspection;
 
-our $VERSION = "0.1";
+our $VERSION = "0.11";
 
 
 # customization ------------------------------------------------------- #
@@ -104,6 +104,7 @@ Gtk3::SourceView - Perl binding for the Gtk3::SourceView widget
 	$textview->set_show_line_numbers(TRUE);
 	$textview->set_wrap_mode("word");
 	$textview->set_highlight_current_line(TRUE);
+	$textview->set_highlight_current_line(TRUE);
 	$textview->set_auto_indent(TRUE);
 
 	# A SIMPLE WORD COMPLETION MODULE
@@ -250,7 +251,7 @@ When the completion is activated, a Gtk3::SourceView::CompletionContext object i
 
 The Gtk3::SourceView::CompletionProposal interface represents a proposal. The Gtk3::SourceView::CompletionItem class is a simple implementation of this interface.
 
-Each Gtk3::SourceView::View object is associated with a Gtk3::SourceView::Completion instance. This instance can be obtained with C<< $view->get_completion(); >>. The Gtk3::SourceView::View class contains also the “show-completion” signal.
+Each Gtk3::SourceView::View object is associated with a Gtk3::SourceView::Completion instance. This instance can be obtained with C<< $view->get_completion(); >>. The Gtk3::SourceView::View class contains also the "show-completion" signal.
 
 A same Gtk3::SourceView::CompletionProvider object can be used for several Gtk3::SourceView::Completion.
 
@@ -397,11 +398,11 @@ Hopefully the following example is helpful for starting. The program search for
 	
 	# two buttons for the search and replace functions
 	my $button_search = Gtk3::Button->new();
-	$button_search->set_label("Search");
+	$button_search->set_label("Suchen");
 	$button_search->signal_connect("clicked" => \&search_cb);
 	
 	my $button_replace = Gtk3::Button->new();
-	$button_replace->set_label("Replace");
+	$button_replace->set_label("Ersetzen");
 	$button_replace->signal_connect("clicked" => \&replace_cb);
 	
 	# a text buffer (stores text)
@@ -449,29 +450,29 @@ Hopefully the following example is helpful for starting. The program search for
 
 		# The single search run
 		# We need a Gtk3::TextIter for the first search run,
-		# because in this run $end is not defined
+		# because there $end is not defined
 		my $startiter = $buffer->get_start_iter();
 		# The Gtk3::SourceView::SearchContext::forward
 		# function returns an array with one Gtk3::Textiter
-		# both start and end position of the search result
-		my @results;
-		# If one search run is already passed, we want to start the 
+		# each start and end position of the search result
+		my @treffer;
+		# If one search run is already passed, wen want to start the 
 		# current search run after the previous search result
 		if ($end) {
 			# Note: To avoid warning, we first check,
 			# whether there is a further result
 			if ($search_context->forward($end)) {
 				# perform the search and save 
-				# the Gtk3::Iters to @results
-				@results = $search_context->forward($end);
+				# the Gtk3::Iters to @treffer
+				@treffer = $search_context->forward($end);
 				# Save the Gtk3::TextIter for 
 				# the start position of the result
 				# in the variable $start
-				$start = @results[0];
+				$start = @treffer[0];
 				# Save the Gtk3::TextIter for 
 				# the end position of the result
 				# in the variable $end
-				$end = @results[1];
+				$end = @treffer[1];
 				# Note: The concept of "current match" 
 				# doesn't exist yet. 
 				# A way to highlight differently 
@@ -482,9 +483,9 @@ Hopefully the following example is helpful for starting. The program search for
 			# from the beginning
 			else {
 				$end = $buffer->get_start_iter();
-				@results = $search_context->forward($end);
-				$start = @results[0];
-				$end = @results[1];
+				@treffer = $search_context->forward($end);
+				$start = @treffer[0];
+				$end = @treffer[1];
 				$buffer->select_range($start, $end);
 			}
 		}
@@ -493,9 +494,9 @@ Hopefully the following example is helpful for starting. The program search for
 		# $startiter which points to the beginning of the buffer
 		else {
 			if ($search_context->forward($startiter)) {
-			@results = $search_context->forward($startiter);
-			$start = @results[0];
-			$end = @results[1];
+			@treffer = $search_context->forward($startiter);
+			$start = @treffer[0];
+			$end = @treffer[1];
 			$buffer->select_range($start, $end);
 		}
 	}
@@ -632,6 +633,8 @@ returned.
 
 =item * L<Gtk3>
 
+=back
+
 =head1 AUTHOR
 
 Maximilian Lika, E<lt>Maximilian-Lika@gmx.de<gt>
